
******************************************************************************************************************************
***************************************************************************************************************************
** Panel. IV [Reduced-Form, First-Stage] Specifications. Unemployment, Construction and Voting
** Robustness 
***Appendix Tables 3, 6, 7
***************************************************************************************************************************
******************************************************************************************************************************


** Appendix Table 3. Lagged Construction Share and Unemployment Panel Region Fixed-Effects OLS Estimates			
***************************************************************************************************************************
***************************************************************************************************************************
gen L1sh_const= L1.sh_const
set more off
xi: xtreg totunemp 				L1sh_const  i.year if nv1==0 & totunemp!=., fe cluster (cntry) 
est store fs1ar

xi: xtreg totunemp 				L1sh_const L1.(sh_agri sh_trade sh_govt sh_finan)  i.year if nv1==0 & totunemp!=., fe cluster (cntry) 
est store fs2ar

xi: xtreg totunemp 				L1sh_const   i.group_year if nv1==0 & totunemp!=., fe cluster (cntry) 
est store fs3ar

xi: xtreg totunemp 				L1sh_const L1.(sh_agri sh_trade sh_govt sh_finan)  i.group_year if nv1==0 & totunemp!=., fe cluster (cntry) 
est store fs4ar
***************************************************************************************************************************


** Appendix Table 3. Lagged Construction Share and Unemployment Panel Region Fixed-Effects OLS Estimates			
** Dependent Variable. Regional Unemployment
***************************************************************************************************************************
***************************************************************************************************************************
** column (1). region and year fixed-effects
** column (2). region and year fixed-effects and other-than-construction industrial shares as controls
** column (3). region and group-year fixed-effects
** column (4). region and group-year fixed-effects and other-than-construction industrial shares as controls
***************************************************************************************************************************
***************************************************************************************************************************
estout fs1ar fs2ar fs3ar fs4ar, cells(b(star fmt(%9.4f)) se(par) t(fmt(%9.2f)))   ///
       keep(L1sh_const)  stats(r2_a r2_w  N N_clust, fmt(%9.3f %9.0g) labels(r-square within-r-square Obs Countries ))  starlevels( * 0.1  ** 0.05  *** 0.01) style(fixed)
	   

	   


** Appendix Table 6. Reduced-Form Estimates
***************************************************************************************************************************
***************************************************************************************************************************

** Panel A. Region (NUTS) and General Year Fixed-Effects
*********************************************************************************************
********************************************************************************************* 
set more off
xi: xtreg extreme_per 		sh_const sh_agri sh_trade sh_govt sh_finan  i.year if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv1rr

xi: xtreg extreme_perel 	sh_const sh_agri sh_trade sh_govt sh_finan  i.year if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv2rr

xi: xtreg extreme_perer 	sh_const sh_agri sh_trade sh_govt sh_finan  i.year if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv3rr

xi: xtreg extreme_perp 		sh_const sh_agri sh_trade sh_govt sh_finan  i.year if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv4rr

xi: xtreg extreme_perae 	sh_const sh_agri sh_trade sh_govt sh_finan  i.year if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv5rr

xi: xtreg part 				sh_const sh_agri sh_trade sh_govt sh_finan  i.year if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv6rr

** Panel B. Region (NUTS) and Period (4-year) time fixed-effects
*************************************************************************************
*************************************************************************************
xi: xtreg extreme_per 		sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv1

xi: xtreg extreme_perel 	sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv2

xi: xtreg extreme_perer 	sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv3

xi: xtreg extreme_perp 		sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv4

xi: xtreg extreme_perae 	sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv5

xi: xtreg part 				sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv6

** Panel C. Region (NUTS) and Country-Group Period (4-year) time fixed-effects
*************************************************************************************
*************************************************************************************
xi: xtreg extreme_per 		sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod_group if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv1r

xi: xtreg extreme_perel 	sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod_group if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv2r

xi: xtreg extreme_perer 	sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod_group if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv3r

xi: xtreg extreme_perp 		sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod_group if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv4r

xi: xtreg extreme_perae 	sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod_group if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv5r

xi: xtreg part 				sh_const sh_agri sh_trade sh_govt sh_finan  i.eperiod_group if nv==0 & totunemp!=., fe cluster (cntry) 
est store rfv6r


		   
** Appendix Table 6. Industrial Regional Composition and Voting for Anti-Establishment Parties "Reduced-Form" Estimates. 2000-2017						
***************************************************************************************************************************
***************************************************************************************************************************
** column (1). Antiestablishment Parties. All Types
** column (2). Voting for Radical Left Parties
** column (3). Voting for Far Right Parties
** column (4). Voting for Populist Parties
** column (5). Voting for Eurosceptic / Separatist parties
** column (6). Participation Rate
***************************************************************************************************************************
***************************************************************************************************************************
** Panel A. General Year Fixed-Effects					
***************************************************************************************************************************
estout rfv1rr rfv2rr rfv3rr rfv4rr rfv5rr rfv6rr, cells(b(star fmt(%9.4f)) se(par) t(fmt(%9.2f)))   ///
       keep(sh_const sh_agri sh_trade sh_govt sh_finan )  stats(r2_a  r2_w N N_clust, fmt(%9.3f %9.0g) labels(r-square  r_within Obs Countries))  starlevels( * 0.1  ** 0.05  *** 0.01) style(fixed)

** Panel B. General Period (4-year) Time Fixed-Effects					
***************************************************************************************************************************
estout rfv1 rfv2 rfv3 rfv4 rfv5 rfv6, cells(b(star fmt(%9.4f)) se(par) t(fmt(%9.2f)))   ///
       keep(sh_const sh_agri sh_trade sh_govt sh_finan )  stats(r2_a  r2_w N N_clust, fmt(%9.3f %9.0g) labels(r-square  r_within Obs Countries))  starlevels( * 0.1  ** 0.05  *** 0.01) style(fixed)	

** Panel C. Country-Group Period (4-year) Time Fixed-Effects					
***************************************************************************************************************************
estout rfv1r rfv2r rfv3r rfv4r rfv5r rfv6r, cells(b(star fmt(%9.4f)) se(par) t(fmt(%9.2f)))   ///
       keep(sh_const sh_agri sh_trade sh_govt sh_finan ) stats(r2_a r2_w N N_clust, fmt(%9.3f %9.0g) labels(r-square  r_within Obs Countries))  starlevels( * 0.1 ** 0.05  *** 0.01) style(fixed)	  



